@@ -1,4 +1,6 @@
 import datetime
+import json
+import collections
 
 from flask import request, current_app
 from flask_restful import reqparse, Resource as RestfulResource, abort, marshal
@@ -13,10 +15,12 @@ from sqlalchemy.util import classproperty, OrderedDict
 import six
 
 from flask_presst.routes import ResourceRoute, route
+from flask_presst.filters import Filter
 from flask_presst.fields import String, Integer, Boolean, List, DateTime, EmbeddedBase, Raw, KeyValue, Arbitrary, \
     Date, Number
 from flask_presst.references import EmbeddedJob, ItemListWrapper, ItemWrapper
 from flask_presst.signals import *
+from flask_presst.routes import ResourceRoute
 from flask_presst.parse import SchemaParser
 
 
@@ -172,7 +176,9 @@ class Resource(six.with_metaclass(ResourceMeta, RestfulResource)):
 
     def get(self, id=None, **kwargs):
         if id is None:
-            return ItemListWrapper.get_list(self).marshal()
+            return ItemListWrapper\
+                .get_list(self)\
+                .apply_filter(request=request).marshal()
         else:
             return ItemWrapper.read(self, id).marshal()
 
@@ -427,10 +433,13 @@ class ModelResourceMeta(ResourceMeta):
                         if column.default is not None and column.default.is_scalar:
                             field_kwargs['default'] = column.default.arg
 
-                        fields[name] = field_class(*field_args, **field_kwargs)
+                        fields[name] = field_class(*field_args, attribute=name, **field_kwargs)
 
                         if not (column.nullable or column.default):
                             required_fields.append(name)
+
+            class_._filter = Filter(model, fields, meta.get('allowed_filters', '*'))
+
         return class_
 
 
@@ -465,6 +474,7 @@ class ModelResource(six.with_metaclass(ModelResourceMeta, Resource)):
     """
     _model = None
     _model_id_column = None
+    _filter = None
 
     @staticmethod
     def _get_field_from_python_type(python_type):
@@ -603,7 +613,7 @@ class ModelResource(six.with_metaclass(ModelResourceMeta, Resource)):
             session.rollback()
             raise
 
-        after_update_item.send(cls, item=item)
+        after_update_item.send(cls, item=item, changes=changes, partial=partial)
         return item
 
     @classmethod
